@@ -954,10 +954,11 @@ class FakeHTTPClient(fakes.FakeHTTPClient):
         if action in ('reset_status', 'reset_replica_state'):
             attr = action.split('reset_')[1]
             assert attr in body.get(action)
-        elif action in ('force_delete', 'resync', 'promote'):
+        elif action in ('force_delete', 'resync'):
             assert body[action] is None
         else:
-            raise AssertionError("Unexpected share action: %s" % action)
+            if action not in ('promote'):
+                raise AssertionError("Unexpected share action: %s" % action)
         return (resp, {}, _body)
 
     #
@@ -1160,6 +1161,24 @@ class FakeHTTPClient(fakes.FakeHTTPClient):
         }]}
         return (200, {}, access_list)
 
+    def delete_snapshots_1234_metadata_test_key(self, **kw):
+        return (204, {}, None)
+
+    def delete_snapshots_1234_metadata_key1(self, **kw):
+        return (204, {}, None)
+
+    def delete_snapshots_1234_metadata_key2(self, **kw):
+        return (204, {}, None)
+
+    def post_snapshots_1234_metadata(self, **kw):
+        return (204, {}, {'metadata': {'test_key': 'test_value'}})
+
+    def put_snapshots_1234_metadata(self, **kw):
+        return (200, {}, {"metadata": {"key1": "val1", "key2": "val2"}})
+
+    def get_snapshots_1234_metadata(self, **kw):
+        return (200, {}, {"metadata": {"key1": "val1", "key2": "val2"}})
+
     def post_snapshot_instances_1234_action(self, body, **kw):
         _body = None
         resp = 202
